@@ -1,8 +1,8 @@
-TRUE_VALS = set(['1', 't', 'true', 'on', 'yes', 'y'])
+TRUE_VALS = {"1", "t", "true", "on", "yes", "y"}
 __unittest = True
 
 
-class Config(object):
+class Config:
 
     """Configuration for a plugin or other entities.
 
@@ -64,8 +64,10 @@ class Config(object):
             return default
         for val in vlist:
             lines.extend(
-                line.strip() for line in val.splitlines()
-                if line.strip() and not line.strip().startswith('#'))
+                line.strip()
+                for line in val.splitlines()
+                if line.strip() and not line.strip().startswith("#")
+            )
         return lines
 
     def get(self, key, default=None):
