@@ -13,12 +13,14 @@ command line.
 # code developed in reference to that module and others within unittest2.
 # unittest2 is Copyright (c) 2001-2010 Python Software Foundation; All
 # Rights Reserved. See: http://docs.python.org/license.html
+
+import inspect
 import logging
+import sys
 import unittest
 
 from nose2 import events, util
 
-
 __unittest = True
 
 
@@ -28,20 +30,23 @@ log = logging.getLogger(__name__)
 class TestCaseLoader(events.Plugin):
 
     """Loader plugin that loads from test cases"""
+
     alwaysOn = True
-    configSection = 'testcases'
+    configSection = "testcases"
 
     def registerInSubprocess(self, event):
         event.pluginClasses.append(self.__class__)
 
     def loadTestsFromModule(self, event):
         """Load tests in :class:`unittest.TestCase` subclasses"""
+        seen = set()
         module = event.module
-        for name in dir(module):
-            obj = getattr(module, name)
+        for _, obj in util.iter_attrs(module):
+            if id(obj) in seen:
+                continue
+            seen.add(id(obj))
             if isinstance(obj, type) and issubclass(obj, unittest.TestCase):
-                event.extraTests.append(
-                    self._loadTestsFromTestCase(event, obj))
+                event.extraTests.append(self._loadTestsFromTestCase(event, obj))
 
     def loadTestsFromName(self, event):
         """Load tests from event.name if it names a test case/method"""
@@ -50,19 +55,21 @@ class TestCaseLoader(events.Plugin):
         log.debug("load %s from %s", name, module)
         try:
             result = util.test_from_name(name, module)
-        except (AttributeError, ImportError) as e:
+        except (AttributeError, ImportError):
             event.handled = True
-            return event.loader.failedLoadTests(name, e)
+            return event.loader.failedLoadTests(name, sys.exc_info())
         if result is None:
             return
         parent, obj, name, index = result
         if isinstance(obj, type) and issubclass(obj, unittest.TestCase):
             # name is a test case class
             event.extraTests.append(self._loadTestsFromTestCase(event, obj))
-        elif (isinstance(parent, type) and
-              issubclass(parent, unittest.TestCase) and not
-              util.isgenerator(obj) and not
-              hasattr(obj, 'paramList')):
+        elif (
+            isinstance(parent, type)
+            and issubclass(parent, unittest.TestCase)
+            and not inspect.isgeneratorfunction(obj)
+            and not hasattr(obj, "paramList")
+        ):
             # name is a single test method
             event.extraTests.append(parent(obj.__name__))
 
@@ -73,8 +80,8 @@ class TestCaseLoader(events.Plugin):
             loaded_suite = result or event.loader.suiteClass()
         else:
             names = self._getTestCaseNames(event, testCaseClass)
-            if not names and hasattr(testCaseClass, 'runTest'):
-                names = ['runTest']
+            if not names and hasattr(testCaseClass, "runTest"):
+                names = ["runTest"]
             # FIXME return failure test case if name not in testcase class
             loaded_suite = event.loader.suiteClass(map(testCaseClass, names))
         if evt.extraTests:
@@ -84,28 +91,26 @@ class TestCaseLoader(events.Plugin):
     def _getTestCaseNames(self, event, testCaseClass):
         excluded = set()
 
-        def isTestMethod(attrname, testCaseClass=testCaseClass,
-                         excluded=excluded):
+        def isTestMethod(attrname, testCaseClass=testCaseClass, excluded=excluded):
             prefix = evt.testMethodPrefix or self.session.testMethodPrefix
             return (
-                attrname.startswith(prefix) and
-                hasattr(getattr(testCaseClass, attrname), '__call__') and
-                attrname not in excluded
+                attrname.startswith(prefix)
+                and hasattr(getattr(testCaseClass, attrname), "__call__")
+                and attrname not in excluded
             )
-        evt = events.GetTestCaseNamesEvent(
-            event.loader, testCaseClass, isTestMethod)
+
+        evt = events.GetTestCaseNamesEvent(event.loader, testCaseClass, isTestMethod)
         result = self.session.hooks.getTestCaseNames(evt)
         if evt.handled:
             test_names = result or []
         else:
             excluded.update(evt.excludedNames)
-            test_names = [entry for entry in dir(testCaseClass)
-                          if isTestMethod(entry)]
+            test_names = [entry for entry in dir(testCaseClass) if isTestMethod(entry)]
         if evt.extraNames:
             test_names.extend(evt.extraNames)
         sortkey = getattr(
-            testCaseClass, 'sortTestMethodsUsing', event.loader.sortTestMethodsUsing)
+            testCaseClass, "sortTestMethodsUsing", event.loader.sortTestMethodsUsing
+        )
         if sortkey:
-            test_names.sort(
-                key=sortkey)
+            test_names.sort(key=sortkey)
         return test_names
