@@ -69,6 +69,7 @@ Here's an example of a test class::
 
 """
 
+import inspect
 import sys
 import unittest
 
@@ -96,14 +97,13 @@ class TestClassLoader(events.Plugin):
         - getTestMethodNames
 
         """
-        super(TestClassLoader, self).register()
+        super().register()
         self.addMethods("loadTestsFromTestClass", "getTestMethodNames")
 
     def loadTestsFromModule(self, event):
         """Load test classes from event.module"""
         module = event.module
-        for name in dir(module):
-            obj = getattr(module, name)
+        for name, obj in util.iter_attrs(module):
             if (
                 isinstance(obj, type)
                 and not issubclass(obj, unittest.TestCase)
@@ -130,7 +130,7 @@ class TestClassLoader(events.Plugin):
         elif (
             isinstance(parent, type)
             and not issubclass(parent, unittest.TestCase)
-            and not util.isgenerator(obj)
+            and not inspect.isgeneratorfunction(obj)
             and not hasattr(obj, "paramList")
         ):
             # name is a single test method
@@ -197,7 +197,7 @@ def MethodTestCase(cls):
     class _MethodTestCase(unittest.TestCase):
         def __init__(self, method):
             self.method = method
-            self._name = "%s.%s.%s" % (cls.__module__, cls.__name__, method)
+            self._name = f"{cls.__module__}.{cls.__name__}.{method}"
             self.obj = cls()
             unittest.TestCase.__init__(self, "runTest")
 
