@@ -10,7 +10,7 @@ from nose2 import events, result
 __unittest = True
 
 
-class PluggableTestRunner(object):
+class PluggableTestRunner:
 
     """Test runner that defers most work to plugins.
 
