@@ -7,7 +7,6 @@ import unittest
 from xml.etree import ElementTree as ET
 
 from nose2 import events, loader, result, session, tools
-from nose2._vendor import six
 from nose2.plugins import junitxml, logcapture
 from nose2.plugins.loader import functions, generators, parameters, testcases
 from nose2.tests._common import TestCase
@@ -24,12 +23,12 @@ def _fromisoformat(date_str):
 class TestJunitXmlPlugin(TestCase):
     _RUN_IN_TEMP = True
 
-    BAD_FOR_XML_U = six.u("A\x07 B\x0B C\x10 D\uD900 " "E\uFFFE F\x80 G\x90 H\uFDDD")
+    BAD_FOR_XML_U = "A\x07 B\x0B C\x10 D\uD900 " "E\uFFFE F\x80 G\x90 H\uFDDD"
     # UTF-8 string with double null (invalid)
-    BAD_FOR_XML_B = six.b(
-        "A\x07 B\x0b C\x10 D\xed\xa4\x80 "
-        "E\xef\xbf\xbe F\xc2\x80 G\xc2\x90 H\xef\xb7\x9d "
-        "\x00\x00"
+    BAD_FOR_XML_B = (
+        b"A\x07 B\x0b C\x10 D\xed\xa4\x80 "
+        b"E\xef\xbf\xbe F\xc2\x80 G\xc2\x90 H\xef\xb7\x9d "
+        b"\x00\x00"
     )
 
     # "byte" strings in PY2 and unicode in py3 works as expected will
@@ -50,15 +49,13 @@ class TestJunitXmlPlugin(TestCase):
     # G\\xc2\\x90 H\\xef\\xb7\\x9d \\x00\\x00"
 
     if sys.maxunicode <= 0xFFFF:
-        EXPECTED_RE = six.u("^[\x09\x0A\x0D\x20\x21-\uD7FF\uE000-\uFFFD]*$")
-        EXPECTED_RE_SAFE = six.u(
+        EXPECTED_RE = "^[\x09\x0A\x0D\x20\x21-\uD7FF\uE000-\uFFFD]*$"
+        EXPECTED_RE_SAFE = (
             "^[\x09\x0A\x0D\x20\x21-\x7E\x85" "\xA0-\uD7FF\uE000-\uFDCF\uFDF0-\uFFFD]*$"
         )
     else:
-        EXPECTED_RE = six.u(
-            "^[\x09\x0A\x0D\x20\x21-\uD7FF\uE000-\uFFFD" "\u10000-\u10FFFF]*$"
-        )
-        EXPECTED_RE_SAFE = six.u(
+        EXPECTED_RE = "^[\x09\x0A\x0D\x20\x21-\uD7FF\uE000-\uFFFD" "\u10000-\u10FFFF]*$"
+        EXPECTED_RE_SAFE = (
             "^[\x09\x0A\x0D\x20\x21-\x7E\x85"
             "\xA0-\uD7FF\uE000-\uFDCF\uFDF0-\uFFFD"
             "\u10000-\u1FFFD\u20000-\u2FFFD"
@@ -72,18 +69,13 @@ class TestJunitXmlPlugin(TestCase):
         )
 
     def setUp(self):
-        super(TestJunitXmlPlugin, self).setUp()
+        super().setUp()
         self.session = session.Session()
         self.loader = loader.PluggableTestLoader(self.session)
         self.result = result.PluggableTestResult(self.session)
         self.plugin = junitxml.JUnitXmlReporter(session=self.session)
         self.plugin.register()
 
-        # Python 2.7 needs this
-        # assertRegexpMatches() was renamed to assertRegex() in 3.2
-        if not hasattr(self, "assertRegex"):
-            self.assertRegex = self.assertRegexpMatches
-
         class Test(unittest.TestCase):
             def test(self):
                 pass
@@ -98,7 +90,7 @@ class TestJunitXmlPlugin(TestCase):
                 assert False
 
             def test_err(self):
-                1 / 0
+                1 / 0  # noqa: B018 useless expression
 
             def test_skip(self):
                 self.skipTest("skip")
@@ -276,7 +268,7 @@ class TestJunitXmlPlugin(TestCase):
         plug2.register()
         # need module to fire top-level event
 
-        class Mod(object):
+        class Mod:
             pass
 
         m = Mod()
@@ -300,7 +292,7 @@ class TestJunitXmlPlugin(TestCase):
         plug2.register()
         # need module to fire top-level event
 
-        class Mod(object):
+        class Mod:
             pass
 
         m = Mod()
@@ -323,7 +315,7 @@ class TestJunitXmlPlugin(TestCase):
         test(self.result)
         event = events.StopTestRunEvent(None, self.result, 1, 1)
         self.plugin.stopTestRun(event)
-        with open(self.plugin.path, "r") as fh:
+        with open(self.plugin.path) as fh:
             tree = ET.parse(fh).getroot()
         self.assertEqual(len(tree.findall("testcase")), 1)
         case = tree.find("testcase")
